#!/usr/bin/env python

from PyQt4 import QtCore, QtGui
import time
import zipfile

class Ui_MainWindow(object):


    def mouseMoveEvent(self, ev):
        if self.FullView.isVisible():
            self.tp2=time.time()
            self.posx2=ev.globalX()
            self.posy2=ev.globalY()
            try:
                selisihtp=self.tp2-self.tp1
                selisihx=self.posx1-self.posx2
                selisihy=self.posy1-self.posy2
            except:
                selisihtp=100
                selisihx=0
                selisihy=0

            if (selisihtp>0.1):
                selisihx=0;
                selisihy=0;
            self.GeserFullImage(selisihx, selisihy)
            self.tp1=self.tp2
            self.posx1=self.posx2
            self.posy1=self.posy2

        else:
            self.tp2=time.time()
            self.pos2=ev.globalY()
            try:
                selisihtp=self.tp2-self.tp1
                selisih=self.pos1-self.pos2
            except:
                selisihtp=100
                selisih=0
            if (selisihtp>0.3): selisih=0;
            self.Geser(selisih)
            self.tp1=self.tp2
            self.pos1=self.pos2

    def mouseDoubleClickEvent(self, ev):
        if self.navWidget.isVisible():
            self.navWidget.hide()
        else:
            self.navWidget.show()


    def GeserFullImage(self, selisihx, selisihy):
        geserx=0
        gesery=0
        self.btkrx=self.FullView.x()
        self.btknx=self.btkrx+self.imgx
        self.btkry=self.FullView.y()
        self.btkny=self.btkry+self.imgy
        #print self.btkrx, self.btknx, self.btkry, self.btkny, selisihx, selisihy
        #print '\n'
        if selisihx<0:
            if self.btkrx<0:
                geserx=1
        if selisihx>0:
            if self.btknx>800:
                geserx=1
        if selisihy<0:
            if self.btkry<0:
                gesery=1
        if selisihy>0:
            if self.btkny>400:
                gesery=1

        if geserx==1:
            self.btkrx=self.btkrx-(selisihx)
	    self.btknx=self.btknx-(selisihx)
            if self.btkrx>0:
                self.btkrx=0;
                self.btknx=self.btkrx+self.imgx
            if self.btknx<800:
                self.btknx=800
                self.btkrx=self.btknx-self.imgx
	    self.FullView.move(self.btkrx, self.btkry)
	if gesery==1:
            self.btkry=self.btkry-(selisihy)
	    self.btkny=self.btkny-(selisihy)
            if self.btkry>0:
                self.btkry=0;
                self.btkny=self.btkry+self.imgy
            if self.btkny<400:
                self.btkny=400
                self.btkry=self.btkny-self.imgy
            self.FullView.move(self.btkrx, self.btkry)


    def Geser(self, langkah):
        geser=0
        if langkah<0:
            if self.batasatas<0:
                geser=1

        if langkah>0:
            if self.batasbawah>400:
                geser=1

        if geser==1:
            self.batasatas=self.batasatas-(langkah)
            self.batasbawah=self.batasbawah-(langkah)
            if self.batasatas>0:
                self.batasatas=0;
                self.batasbawah=self.batasatas+self.panjang
            if self.batasbawah<400:
                self.batasbawah=400;
                self.batasatas=self.batasbawah-self.panjang
            self.widget.move(0,self.batasatas)


    def showPage(self, strpage):
        myzipfile='/home/user/MyDocs/.documents/quran/qdata_for_quran1.0.0.qdb'
        zfile=zipfile.ZipFile(myzipfile, "r")
        p=zfile.read(strpage)
        img=QtGui.QImage()
        img.loadFromData(p, "JPG")
        image = QtGui.QPixmap()
        image=QtGui.QPixmap.fromImage(img)
        #image = QtGui.QPixmap(p,'JPG')
        self.imgx=image.width()
        self.imgy=image.height()

        scale=770/float(self.imgx)
        image=image.scaled(770, round(self.imgy*scale))
        self.imgx=image.width()
        self.imgy=image.height()

        self.FullView.setGeometry(QtCore.QRect(5, 5, 795, 400))
	self.FullView.setMinimumSize(QtCore.QSize(self.imgx, self.imgy))

        scene=QtGui.QGraphicsScene()
        scene.addPixmap(image)
        self.FullView.setScene(scene)
        self.MW.showFullScreen()
        self.labelPage.setText(str(self.page))

    def openNext(self):
        self.FullView.setFocus()
        if self.page<self.maxpage:
            self.page=self.page+1
            self.showPage(self.Page2String())

    def openPrev(self):
        self.FullView.setFocus()
        if self.page>self.minpage:
            self.page=self.page-1
            self.showPage(self.Page2String())

    def Page2String(self):
        strpage='tf'+str(self.page)+'.arb'
        return strpage

    def setVisibility(self):
        self.widget.hide()
        self.FullView.show()
        self.navWidget.show()
        self.FullView.setFocus()

    def backtoIndex(self):
        self.FullView.hide()
        self.navWidget.hide()
        self.MW.showNormal()
        self.widget.show()

    def closeApp(self):
        self.MW.close()

    def showAbout(self):
        msgProgramName=" \nQuran Mobile for Nokia N900"
        msgAuthor="(c) Barakuba (aridho@gmail.com)\n "
        msgVersion="Version 1.0.0\n "
        msg=msgProgramName+'\n'+msgAuthor+msgVersion
        QtGui.QMessageBox.information(None, 'About',msg, QtGui.QMessageBox.Close)

    def showGoto(self):
	text, ok = QtGui.QInputDialog.getText(None, "Go to", "Go to page:", 0)
	text=int(text)
	if ok:
	    if (text>=self.minpage) and (text<=self.maxpage):
                self.page=text
                self.setVisibility()
                self.showPage(self.Page2String())

    def savePage(self):
        s=str(self.page)

	f = open('/usr/lib/quran/quran_track.ptr', "w")
        f.write(s)
        f.close()
        QtGui.QMessageBox.information(None, 'Save','This page is already saved', QtGui.QMessageBox.Close)
        self.FullView.setFocus()


    def loadPage(self):
        f = QtCore.QFile('/usr/lib/quran/quran_track.ptr')
        f.open(QtCore.QIODevice.ReadOnly)
        strpage=QtCore.QTextStream(f).readLine()
        self.page=int(strpage)
	self.setVisibility()
        self.showPage(self.Page2String())

    def keyPressEvent(self, ev):
        nilai=ev.key()
        if nilai==16777237:
            self.GeserFullImage(0, 30)
        elif nilai==32:
            self.GeserFullImage(0, 400)
        elif nilai==16777235:
            self.GeserFullImage(0, -30)
        elif nilai==16777234:
            self.openNext()
        elif nilai==16777236:
            self.openPrev()






    def openAlfatehah(self):
        self.page=1
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlbaqoroh(self):
        self.page=2
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAliimron(self):
        self.page=45
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnisa(self):
        self.page=69
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmaidah(self):
        self.page=95
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnanam(self):
        self.page=115
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlarof(self):
        self.page=136
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlanfal(self):
        self.page=160
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAttaubah(self):
        self.page=169
        self.setVisibility()
        self.showPage(self.Page2String())

    def openYunus(self):
        self.page=187
        self.setVisibility()
        self.showPage(self.Page2String())

    def openHud(self):
        self.page=199
        self.setVisibility()
        self.showPage(self.Page2String())

    def openYusuf(self):
        self.page=212
        self.setVisibility()
        self.showPage(self.Page2String())

    def openArroed(self):
        self.page=225
        self.setVisibility()
        self.showPage(self.Page2String())

    def openIbrohim(self):
        self.page=231
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlhijr(self):
        self.page=237
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnahl(self):
        self.page=242
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlisro(self):
        self.page=255
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlkahf(self):
        self.page=266
        self.setVisibility()
        self.showPage(self.Page2String())

    def openMaryam(self):
        self.page=277
        self.setVisibility()
        self.showPage(self.Page2String())

    def openThoha(self):
        self.page=284
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlanbiya(self):
        self.page=294
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlhaaj(self):
        self.page=302
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmukminun(self):
        self.page=311
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnuur(self):
        self.page=319
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlfurqon(self):
        self.page=329
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAssyuaro(self):
        self.page=335
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnaml(self):
        self.page=345
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlqoshosh(self):
        self.page=354
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlankabut(self):
        self.page=364
        self.setVisibility()
        self.showPage(self.Page2String())

    def openArruum(self):
        self.page=371
        self.setVisibility()
        self.showPage(self.Page2String())

    def openLuqman(self):
        self.page=377
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAssajadah(self):
        self.page=381
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlahzab(self):
        self.page=383
        self.setVisibility()
        self.showPage(self.Page2String())

    def openSaba(self):
        self.page=393
        self.setVisibility()
        self.showPage(self.Page2String())

    def openFaathir(self):
        self.page=399
        self.setVisibility()
        self.showPage(self.Page2String())

    def openYasin(self):
        self.page=404
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAsshoffaat(self):
        self.page=410
        self.setVisibility()
        self.showPage(self.Page2String())

    def openShoot(self):
        self.page=417
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAzzumar(self):
        self.page=422
        self.setVisibility()
        self.showPage(self.Page2String())

    def openGhoofir(self):
        self.page=431
        self.setVisibility()
        self.showPage(self.Page2String())

    def openFusshilat(self):
        self.page=439
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAssyuuroo(self):
        self.page=445
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAzzukhruf(self):
        self.page=451
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAddukhon(self):
        self.page=457
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAljaatsiyah(self):
        self.page=460
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlahqoof(self):
        self.page=464
        self.setVisibility()
        self.showPage(self.Page2String())

    def openMuhammad(self):
        self.page=468
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlfath(self):
        self.page=472
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlhujurat(self):
        self.page=477
        self.setVisibility()
        self.showPage(self.Page2String())

    def openQoof(self):
        self.page=479
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAddzaariyat(self):
        self.page=482
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAtthuur(self):
        self.page=485
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnajm(self):
        self.page=487
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlqomar(self):
        self.page=490
        self.setVisibility()
        self.showPage(self.Page2String())

    def openArrohman(self):
        self.page=493
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlwaqiah(self):
        self.page=496
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlhadid(self):
        self.page=499
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmujadalah(self):
        self.page=504
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlhasyr(self):
        self.page=507
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmumtahinah(self):
        self.page=510
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAsshof(self):
        self.page=513
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAljumah(self):
        self.page=515
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmunafiqun(self):
        self.page=516
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAttaghobun(self):
        self.page=518
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAttholaq(self):
        self.page=520
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAttahrim(self):
        self.page=522
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmulk(self):
        self.page=524
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlqolam(self):
        self.page=526
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlhaqqoh(self):
        self.page=529
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmaarij(self):
        self.page=531
        self.setVisibility()
        self.showPage(self.Page2String())

    def openNuh(self):
        self.page=533
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAljin(self):
        self.page=534
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmuzammil(self):
        self.page=537
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmudatstsir(self):
        self.page=538
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlqiyamah(self):
        self.page=540
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlinsan(self):
        self.page=542
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmursalat(self):
        self.page=544
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnaba(self):
        self.page=545
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnaziat(self):
        self.page=547
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAbasa(self):
        self.page=548
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAttakwir(self):
        self.page=550
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlinfithor(self):
        self.page=551
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmuthoffifin(self):
        self.page=552
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlinsyiqoq(self):
        self.page=553
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlburuj(self):
        self.page=554
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAtthoriq(self):
        self.page=555
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAla3la(self):
        self.page=556
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlghosyiyah(self):
        self.page=556
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlfajr(self):
        self.page=557
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlbalad(self):
        self.page=559
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAssyams(self):
        self.page=559
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAllail(self):
        self.page=560
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAddhuha(self):
        self.page=561
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAssyarh(self):
        self.page=561
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAtthin(self):
        self.page=562
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlalaq(self):
        self.page=562
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlqodar(self):
        self.page=563
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlbayyinah(self):
        self.page=563
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlzalzalah(self):
        self.page=564
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAladiyat(self):
        self.page=564
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlqoriah(self):
        self.page=565
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAttakatsur(self):
        self.page=565
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlashr(self):
        self.page=566
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlhumazah(self):
        self.page=566
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlfiil(self):
        self.page=566
        self.setVisibility()
        self.showPage(self.Page2String())

    def openQuraisy(self):
        self.page=567
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmaun(self):
        self.page=567
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlkautsar(self):
        self.page=567
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlkafirun(self):
        self.page=568
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnashr(self):
        self.page=568
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlmasad(self):
        self.page=568
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlikhlas(self):
        self.page=569
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAlfalaq(self):
        self.page=569
        self.setVisibility()
        self.showPage(self.Page2String())

    def openAnnas(self):
        self.page=569
        self.setVisibility()
        self.showPage(self.Page2String())





#------------------------------------------------------------------------
    def setupUi(self, MainWindow):
        self.MW=MainWindow
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(800, 400)
        MainWindow.setMinimumSize(QtCore.QSize(800, 400))
        MainWindow.setMouseTracking(True)

        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        #self.centralwidget.setStyleSheet("background-color: rgb(255, 255, 0);")
        self.widget = QtGui.QWidget(self.centralwidget)
        self.widget.setGeometry(QtCore.QRect(0, 0, 800, 780))
        self.widget.setMinimumSize(QtCore.QSize(800, 780))
        self.widget.setObjectName("widget")
        self.widget.mouseMoveEvent = self.mouseMoveEvent
        self.panjang=780
        self.batasatas=0;
        self.batasbawah=self.panjang;

        self.FullView=QtGui.QGraphicsView(self.centralwidget)
        self.FullView.setMinimumSize(QtCore.QSize(790, 400))
        self.FullView.setAlignment(QtCore.Qt.AlignCenter)
        self.FullView.setStyleSheet("background-color: rgb(255, 255, 230);")
        self.FullView.setObjectName('FullView')
        self.FullView.hide()
        self.FullView.setGeometry(QtCore.QRect(5, 5, 790, 400))
        self.FullView.mouseMoveEvent = self.mouseMoveEvent
        self.FullView.mouseDoubleClickEvent = self.mouseDoubleClickEvent
        self.FullView.keyPressEvent = self.keyPressEvent
        self.FullView.setHorizontalScrollBarPolicy(1)
        self.FullView.setVerticalScrollBarPolicy(1)
        self.FullView.setAlignment(QtCore.Qt.AlignCenter)



        self.navWidget= QtGui.QWidget()
        self.navWidget = QtGui.QWidget(self.centralwidget)
        self.navWidget = QtGui.QWidget(MainWindow)
        self.navWidget.setStyleSheet("background-color: rgb(0, 0, 0);")
        self.navWidget.setGeometry(QtCore.QRect(0, 400, 800, 470))
        self.navWidget.setMinimumSize(QtCore.QSize(180, 280))
        self.navWidget.setObjectName("navWidget")
        self.navWidget.hide()

        self.btnNext = QtGui.QPushButton(self.navWidget)
        self.btnNext.setGeometry(QtCore.QRect(20, 0, 120, 70))
        self.btnNext.setMinimumSize(QtCore.QSize(100, 70))
        self.btnNext.setStyleSheet("font: 18pt \"MS Shell Dlg 2\";")
        self.btnNext.setObjectName("btnNext")

        self.labelPage = QtGui.QLabel(self.navWidget)
        self.labelPage.setGeometry(QtCore.QRect(160, 0, 60, 70))
        self.labelPage.setStyleSheet("font: 18pt \"MS Shell Dlg 2\";")
        self.labelPage.setObjectName("labelPage")
        self.labelPage.setAlignment(QtCore.Qt.AlignCenter)

        self.btnSave = QtGui.QPushButton(self.navWidget)
        self.btnSave.setGeometry(QtCore.QRect(240, 0, 120, 70))
        self.btnSave.setMinimumSize(QtCore.QSize(120, 70))
        self.btnSave.setStyleSheet("font: 18pt \"MS Shell Dlg 2\";")
        self.btnSave.setObjectName("btnSave")

        self.btnExit = QtGui.QPushButton(self.navWidget)
        self.btnExit.setGeometry(QtCore.QRect(380, 0, 120, 70))
        self.btnExit.setMinimumSize(QtCore.QSize(120, 70))
        self.btnExit.setStyleSheet("font: 18pt \"MS Shell Dlg 2\";")
        self.btnExit.setObjectName("btnExit")

        self.btnIndex = QtGui.QPushButton(self.navWidget)
        self.btnIndex.setGeometry(QtCore.QRect(520, 0, 120, 70))
        self.btnIndex.setMinimumSize(QtCore.QSize(120, 70))
        self.btnIndex.setStyleSheet("font: 18pt \"MS Shell Dlg 2\";")
        self.btnIndex.setObjectName("btnIndex")

        self.btnPrev = QtGui.QPushButton(self.navWidget)
        self.btnPrev.setGeometry(QtCore.QRect(660, 0, 120, 70))
        self.btnPrev.setMinimumSize(QtCore.QSize(100, 70))
        self.btnPrev.setStyleSheet("font: 18pt \"MS Shell Dlg 2\";")
        self.btnPrev.setObjectName("btnPrev")






        self.btnAlfatehah = QtGui.QPushButton(self.widget)
        self.btnAlfatehah.setGeometry(QtCore.QRect(660, 10, 131, 42))
        self.btnAlfatehah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlfatehah.setStyleSheet("background-image: url(:/images/alfatehah.jpg);")
        self.btnAlfatehah.setObjectName("btnAlfatehah")
        self.btnAlbaqoroh = QtGui.QPushButton(self.widget)
        self.btnAlbaqoroh.setGeometry(QtCore.QRect(660, 50, 131, 42))
        self.btnAlbaqoroh.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlbaqoroh.setStyleSheet("background-image: url(:/images/albaqoroh.jpg);")
        self.btnAlbaqoroh.setObjectName("btnAlbaqoroh")
        self.btnAliimron = QtGui.QPushButton(self.widget)
        self.btnAliimron.setGeometry(QtCore.QRect(660, 90, 131, 42))
        self.btnAliimron.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAliimron.setStyleSheet("background-image: url(:/images/aliimron.jpg);")
        self.btnAliimron.setObjectName("btnAliimron")
        self.btnAnnisa = QtGui.QPushButton(self.widget)
        self.btnAnnisa.setGeometry(QtCore.QRect(660, 130, 131, 42))
        self.btnAnnisa.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnisa.setStyleSheet("background-image: url(:/images/annisa.jpg);")
        self.btnAnnisa.setObjectName("btnAnnisa")
        self.btnAlmaidah = QtGui.QPushButton(self.widget)
        self.btnAlmaidah.setGeometry(QtCore.QRect(660, 170, 131, 42))
        self.btnAlmaidah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmaidah.setStyleSheet("background-image: url(:/images/almaidah.jpg);")
        self.btnAlmaidah.setObjectName("btnAlmaidah")
        self.btnAnanam = QtGui.QPushButton(self.widget)
        self.btnAnanam.setGeometry(QtCore.QRect(660, 210, 131, 42))
        self.btnAnanam.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnanam.setStyleSheet("background-image: url(:/images/alanam.jpg);")
        self.btnAnanam.setObjectName("btnAnanam")
        self.btnAlarof = QtGui.QPushButton(self.widget)
        self.btnAlarof.setGeometry(QtCore.QRect(660, 250, 131, 42))
        self.btnAlarof.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlarof.setStyleSheet("background-image: url(:/images/alarof.jpg);")
        self.btnAlarof.setObjectName("btnAlarof")
        self.btnHud = QtGui.QPushButton(self.widget)
        self.btnHud.setGeometry(QtCore.QRect(660, 410, 131, 42))
        self.btnHud.setMinimumSize(QtCore.QSize(131, 42))
        self.btnHud.setStyleSheet("background-image: url(:/images/hud.jpg);")
        self.btnHud.setObjectName("btnHud")
        self.btnArroed = QtGui.QPushButton(self.widget)
        self.btnArroed.setGeometry(QtCore.QRect(660, 490, 131, 42))
        self.btnArroed.setMinimumSize(QtCore.QSize(131, 42))
        self.btnArroed.setStyleSheet("background-image: url(:/images/arroed.jpg);")
        self.btnArroed.setObjectName("btnArroed")
        self.btnYunus = QtGui.QPushButton(self.widget)
        self.btnYunus.setGeometry(QtCore.QRect(660, 370, 131, 42))
        self.btnYunus.setMinimumSize(QtCore.QSize(131, 42))
        self.btnYunus.setStyleSheet("background-image: url(:/images/yunus.jpg);")
        self.btnYunus.setObjectName("btnYunus")
        self.btnAlanfal = QtGui.QPushButton(self.widget)
        self.btnAlanfal.setGeometry(QtCore.QRect(660, 290, 131, 42))
        self.btnAlanfal.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlanfal.setStyleSheet("background-image: url(:/images/ananfal.jpg);")
        self.btnAlanfal.setObjectName("btnAlanfal")
        self.btnAttaubah = QtGui.QPushButton(self.widget)
        self.btnAttaubah.setGeometry(QtCore.QRect(660, 330, 131, 42))
        self.btnAttaubah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAttaubah.setStyleSheet("background-image: url(:/images/attaubah.jpg);")
        self.btnAttaubah.setObjectName("btnAttaubah")
        self.btnYusuf = QtGui.QPushButton(self.widget)
        self.btnYusuf.setGeometry(QtCore.QRect(660, 450, 131, 42))
        self.btnYusuf.setMinimumSize(QtCore.QSize(131, 42))
        self.btnYusuf.setStyleSheet("background-image: url(:/images/yusuf.jpg);")
        self.btnYusuf.setObjectName("btnYusuf")
        self.btnIbrohim = QtGui.QPushButton(self.widget)
        self.btnIbrohim.setGeometry(QtCore.QRect(660, 530, 131, 42))
        self.btnIbrohim.setMinimumSize(QtCore.QSize(131, 42))
        self.btnIbrohim.setStyleSheet("background-image: url(:/images/ibrohim.jpg);")
        self.btnIbrohim.setObjectName("btnIbrohim")
        self.btnMaryam = QtGui.QPushButton(self.widget)
        self.btnMaryam.setGeometry(QtCore.QRect(660, 730, 131, 42))
        self.btnMaryam.setMinimumSize(QtCore.QSize(131, 42))
        self.btnMaryam.setStyleSheet("background-image: url(:/images/maryam.jpg);")
        self.btnMaryam.setObjectName("btnMaryam")
        self.btnThoha = QtGui.QPushButton(self.widget)
        self.btnThoha.setGeometry(QtCore.QRect(530, 10, 131, 42))
        self.btnThoha.setMinimumSize(QtCore.QSize(131, 42))
        self.btnThoha.setStyleSheet("background-image: url(:/images/thoha.jpg);")
        self.btnThoha.setObjectName("btnThoha")
        self.btnAlhijr = QtGui.QPushButton(self.widget)
        self.btnAlhijr.setGeometry(QtCore.QRect(660, 570, 131, 42))
        self.btnAlhijr.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlhijr.setStyleSheet("background-image: url(:/images/alhijr.jpg);")
        self.btnAlhijr.setObjectName("btnAlhijr")
        self.btnAlanbiya = QtGui.QPushButton(self.widget)
        self.btnAlanbiya.setGeometry(QtCore.QRect(530, 50, 131, 42))
        self.btnAlanbiya.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlanbiya.setStyleSheet("background-image: url(:/images/alanbiya.jpg);")
        self.btnAlanbiya.setObjectName("btnAlanbiya")
        self.btnAlisro = QtGui.QPushButton(self.widget)
        self.btnAlisro.setGeometry(QtCore.QRect(660, 650, 131, 42))
        self.btnAlisro.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlisro.setStyleSheet("background-image: url(:/images/alisro.jpg);")
        self.btnAlisro.setObjectName("btnAlisro")
        self.btnAnnahl = QtGui.QPushButton(self.widget)
        self.btnAnnahl.setGeometry(QtCore.QRect(660, 610, 131, 42))
        self.btnAnnahl.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnahl.setStyleSheet("background-image: url(:/images/annahl.jpg);")
        self.btnAnnahl.setObjectName("btnAnnahl")
        self.btnAssyuaro = QtGui.QPushButton(self.widget)
        self.btnAssyuaro.setGeometry(QtCore.QRect(530, 250, 131, 42))
        self.btnAssyuaro.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAssyuaro.setStyleSheet("background-image: url(:/images/assyuaro.jpg);")
        self.btnAssyuaro.setObjectName("btnAssyuaro")
        self.btnAnnaml = QtGui.QPushButton(self.widget)
        self.btnAnnaml.setGeometry(QtCore.QRect(530, 290, 131, 42))
        self.btnAnnaml.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnaml.setStyleSheet("background-image: url(:/images/annaml.jpg);")
        self.btnAnnaml.setObjectName("btnAnnaml")
        self.btnAlhaaj = QtGui.QPushButton(self.widget)
        self.btnAlhaaj.setGeometry(QtCore.QRect(530, 90, 131, 42))
        self.btnAlhaaj.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlhaaj.setStyleSheet("background-image: url(:/images/alhaaj.jpg);")
        self.btnAlhaaj.setObjectName("btnAlhaaj")
        self.btnAlqoshosh = QtGui.QPushButton(self.widget)
        self.btnAlqoshosh.setGeometry(QtCore.QRect(530, 330, 131, 42))
        self.btnAlqoshosh.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlqoshosh.setStyleSheet("background-image: url(:/images/alqoshosh.jpg);")
        self.btnAlqoshosh.setObjectName("btnAlqoshosh")
        self.btnAnnuur = QtGui.QPushButton(self.widget)
        self.btnAnnuur.setGeometry(QtCore.QRect(530, 170, 131, 42))
        self.btnAnnuur.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnuur.setStyleSheet("background-image: url(:/images/annuur.jpg);")
        self.btnAnnuur.setObjectName("btnAnnuur")
        self.btnAlmukminun = QtGui.QPushButton(self.widget)
        self.btnAlmukminun.setGeometry(QtCore.QRect(530, 130, 131, 42))
        self.btnAlmukminun.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmukminun.setStyleSheet("background-image: url(:/images/almukminun.jpg);")
        self.btnAlmukminun.setObjectName("btnAlmukminun")
        self.btnAlfurqon = QtGui.QPushButton(self.widget)
        self.btnAlfurqon.setGeometry(QtCore.QRect(530, 210, 131, 42))
        self.btnAlfurqon.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlfurqon.setStyleSheet("background-image: url(:/images/alfurqon.jpg);")
        self.btnAlfurqon.setObjectName("btnAlfurqon")
        self.btnAlahzab = QtGui.QPushButton(self.widget)
        self.btnAlahzab.setGeometry(QtCore.QRect(530, 530, 131, 42))
        self.btnAlahzab.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlahzab.setStyleSheet("background-image: url(:/images/alahzab.jpg);")
        self.btnAlahzab.setObjectName("btnAlahzab")
        self.btnSaba = QtGui.QPushButton(self.widget)
        self.btnSaba.setGeometry(QtCore.QRect(530, 570, 131, 42))
        self.btnSaba.setMinimumSize(QtCore.QSize(131, 42))
        self.btnSaba.setStyleSheet("background-image: url(:/images/saba.jpg);")
        self.btnSaba.setObjectName("btnSaba")
        self.btnAlankabut = QtGui.QPushButton(self.widget)
        self.btnAlankabut.setGeometry(QtCore.QRect(530, 370, 131, 42))
        self.btnAlankabut.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlankabut.setStyleSheet("background-image: url(:/images/alankabut.jpg);")
        self.btnAlankabut.setObjectName("btnAlankabut")
        self.btnFaathir = QtGui.QPushButton(self.widget)
        self.btnFaathir.setGeometry(QtCore.QRect(530, 610, 131, 42))
        self.btnFaathir.setMinimumSize(QtCore.QSize(131, 42))
        self.btnFaathir.setStyleSheet("background-image: url(:/images/faathir.jpg);")
        self.btnFaathir.setObjectName("btnFaathir")
        self.btnLuqman = QtGui.QPushButton(self.widget)
        self.btnLuqman.setGeometry(QtCore.QRect(530, 450, 131, 42))
        self.btnLuqman.setMinimumSize(QtCore.QSize(131, 42))
        self.btnLuqman.setStyleSheet("background-image: url(:/images/luqman.jpg);")
        self.btnLuqman.setObjectName("btnLuqman")
        self.btnArruum = QtGui.QPushButton(self.widget)
        self.btnArruum.setGeometry(QtCore.QRect(530, 410, 131, 42))
        self.btnArruum.setMinimumSize(QtCore.QSize(131, 42))
        self.btnArruum.setStyleSheet("background-image: url(:/images/arruum.jpg);")
        self.btnArruum.setObjectName("btnArruum")
        self.btnAssajadah = QtGui.QPushButton(self.widget)
        self.btnAssajadah.setGeometry(QtCore.QRect(530, 490, 131, 42))
        self.btnAssajadah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAssajadah.setStyleSheet("background-image: url(:/images/assajadah.jpg);")
        self.btnAssajadah.setObjectName("btnAssajadah")
        self.btnGhoofir = QtGui.QPushButton(self.widget)
        self.btnGhoofir.setGeometry(QtCore.QRect(400, 50, 131, 42))
        self.btnGhoofir.setMinimumSize(QtCore.QSize(131, 42))
        self.btnGhoofir.setStyleSheet("background-image: url(:/images/ghoofir.jpg);")
        self.btnGhoofir.setObjectName("btnGhoofir")
        self.btnFusshilat = QtGui.QPushButton(self.widget)
        self.btnFusshilat.setGeometry(QtCore.QRect(400, 90, 131, 42))
        self.btnFusshilat.setMinimumSize(QtCore.QSize(131, 42))
        self.btnFusshilat.setStyleSheet("background-image: url(:/images/fusshilat.jpg);")
        self.btnFusshilat.setObjectName("btnFusshilat")
        self.btnYasin = QtGui.QPushButton(self.widget)
        self.btnYasin.setGeometry(QtCore.QRect(530, 650, 131, 42))
        self.btnYasin.setMinimumSize(QtCore.QSize(131, 42))
        self.btnYasin.setStyleSheet("background-image: url(:/images/yasin.jpg);")
        self.btnYasin.setObjectName("btnYasin")
        self.btnAssyuuroo = QtGui.QPushButton(self.widget)
        self.btnAssyuuroo.setGeometry(QtCore.QRect(400, 130, 131, 42))
        self.btnAssyuuroo.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAssyuuroo.setStyleSheet("background-image: url(:/images/assyuuroo.jpg);")
        self.btnAssyuuroo.setObjectName("btnAssyuuroo")
        self.btnShoot = QtGui.QPushButton(self.widget)
        self.btnShoot.setGeometry(QtCore.QRect(530, 730, 131, 42))
        self.btnShoot.setMinimumSize(QtCore.QSize(131, 42))
        self.btnShoot.setStyleSheet("background-image: url(:/images/shoot.jpg);")
        self.btnShoot.setObjectName("btnShoot")
        self.btnAsshoffaat = QtGui.QPushButton(self.widget)
        self.btnAsshoffaat.setGeometry(QtCore.QRect(530, 690, 131, 42))
        self.btnAsshoffaat.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAsshoffaat.setStyleSheet("background-image: url(:/images/asshoffaat.jpg);")
        self.btnAsshoffaat.setObjectName("btnAsshoffaat")
        self.btnAzzumar = QtGui.QPushButton(self.widget)
        self.btnAzzumar.setGeometry(QtCore.QRect(400, 10, 131, 42))
        self.btnAzzumar.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAzzumar.setStyleSheet("background-image: url(:/images/azzumar.jpg);")
        self.btnAzzumar.setObjectName("btnAzzumar")
        self.btnMuhammad = QtGui.QPushButton(self.widget)
        self.btnMuhammad.setGeometry(QtCore.QRect(400, 330, 131, 42))
        self.btnMuhammad.setMinimumSize(QtCore.QSize(131, 42))
        self.btnMuhammad.setStyleSheet("background-image: url(:/images/muhammad.jpg);")
        self.btnMuhammad.setObjectName("btnMuhammad")
        self.btnAlfath = QtGui.QPushButton(self.widget)
        self.btnAlfath.setGeometry(QtCore.QRect(400, 370, 131, 42))
        self.btnAlfath.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlfath.setStyleSheet("background-image: url(:/images/alfath.jpg);")
        self.btnAlfath.setObjectName("btnAlfath")
        self.btnAzzukhruf = QtGui.QPushButton(self.widget)
        self.btnAzzukhruf.setGeometry(QtCore.QRect(400, 170, 131, 42))
        self.btnAzzukhruf.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAzzukhruf.setStyleSheet("background-image: url(:/images/azzukhruf.jpg);")
        self.btnAzzukhruf.setObjectName("btnAzzukhruf")
        self.btnAlhujurat = QtGui.QPushButton(self.widget)
        self.btnAlhujurat.setGeometry(QtCore.QRect(400, 410, 131, 42))
        self.btnAlhujurat.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlhujurat.setStyleSheet("background-image: url(:/images/alhujurat.jpg);")
        self.btnAlhujurat.setObjectName("btnAlhujurat")
        self.btnAddukhon = QtGui.QPushButton(self.widget)
        self.btnAddukhon.setGeometry(QtCore.QRect(400, 210, 131, 42))
        self.btnAddukhon.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAddukhon.setStyleSheet("background-image: url(:/images/addukhon.jpg);")
        self.btnAddukhon.setObjectName("btnAddukhon")
        self.btnAlahqoof = QtGui.QPushButton(self.widget)
        self.btnAlahqoof.setGeometry(QtCore.QRect(400, 290, 131, 42))
        self.btnAlahqoof.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlahqoof.setStyleSheet("background-image: url(:/images/alahqoof.jpg);")
        self.btnAlahqoof.setObjectName("btnAlahqoof")
        self.btnAlqomar = QtGui.QPushButton(self.widget)
        self.btnAlqomar.setGeometry(QtCore.QRect(400, 610, 131, 42))
        self.btnAlqomar.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlqomar.setStyleSheet("background-image: url(:/images/alqomar.jpg);")
        self.btnAlqomar.setObjectName("btnAlqomar")
        self.btnQoof = QtGui.QPushButton(self.widget)
        self.btnQoof.setGeometry(QtCore.QRect(400, 450, 131, 42))
        self.btnQoof.setMinimumSize(QtCore.QSize(131, 42))
        self.btnQoof.setStyleSheet("background-image: url(:/images/qoof.jpg);")
        self.btnQoof.setObjectName("btnQoof")
        self.btnAtthuur = QtGui.QPushButton(self.widget)
        self.btnAtthuur.setGeometry(QtCore.QRect(400, 530, 131, 42))
        self.btnAtthuur.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAtthuur.setStyleSheet("background-image: url(:/images/atthuur.jpg);")
        self.btnAtthuur.setObjectName("btnAtthuur")
        self.btnAddzaariyat = QtGui.QPushButton(self.widget)
        self.btnAddzaariyat.setGeometry(QtCore.QRect(400, 490, 131, 42))
        self.btnAddzaariyat.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAddzaariyat.setStyleSheet("background-image: url(:/images/addzaariyat.jpg);")
        self.btnAddzaariyat.setObjectName("btnAddzaariyat")
        self.btnAnnajm = QtGui.QPushButton(self.widget)
        self.btnAnnajm.setGeometry(QtCore.QRect(400, 570, 131, 42))
        self.btnAnnajm.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnajm.setStyleSheet("background-image: url(:/images/annajm.jpg);")
        self.btnAnnajm.setObjectName("btnAnnajm")
        self.btnAlkahf = QtGui.QPushButton(self.widget)
        self.btnAlkahf.setGeometry(QtCore.QRect(660, 690, 131, 42))
        self.btnAlkahf.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlkahf.setStyleSheet("background-image: url(:/images/alkahf.jpg);")
        self.btnAlkahf.setObjectName("btnAlkahf")
        self.btnAljaatsiyah = QtGui.QPushButton(self.widget)
        self.btnAljaatsiyah.setGeometry(QtCore.QRect(400, 250, 131, 42))
        self.btnAljaatsiyah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAljaatsiyah.setStyleSheet("background-image: url(:/images/aljaatsiyah.jpg);")
        self.btnAljaatsiyah.setObjectName("btnAljaatsiyah")
        self.btnArrohman = QtGui.QPushButton(self.widget)
        self.btnArrohman.setGeometry(QtCore.QRect(400, 650, 131, 42))
        self.btnArrohman.setMinimumSize(QtCore.QSize(131, 42))
        self.btnArrohman.setStyleSheet("background-image: url(:/images/arrohman.jpg);")
        self.btnArrohman.setObjectName("btnArrohman")
        self.btnAlwaqiah = QtGui.QPushButton(self.widget)
        self.btnAlwaqiah.setGeometry(QtCore.QRect(400, 690, 131, 42))
        self.btnAlwaqiah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlwaqiah.setStyleSheet("background-image: url(:/images/alwaqiah.jpg);")
        self.btnAlwaqiah.setObjectName("btnAlwaqiah")
        self.btnAlhadid = QtGui.QPushButton(self.widget)
        self.btnAlhadid.setGeometry(QtCore.QRect(400, 730, 131, 42))
        self.btnAlhadid.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlhadid.setStyleSheet("background-image: url(:/images/alhadid.jpg);")
        self.btnAlhadid.setObjectName("btnAlhadid")
        self.btnAlmujadalah = QtGui.QPushButton(self.widget)
        self.btnAlmujadalah.setGeometry(QtCore.QRect(270, 10, 131, 42))
        self.btnAlmujadalah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmujadalah.setStyleSheet("background-image: url(:/images/almujadalah.jpg);")
        self.btnAlmujadalah.setObjectName("btnAlmujadalah")
        self.btnAlhasyr = QtGui.QPushButton(self.widget)
        self.btnAlhasyr.setGeometry(QtCore.QRect(270, 50, 131, 42))
        self.btnAlhasyr.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlhasyr.setStyleSheet("background-image: url(:/images/alhasyr.jpg);")
        self.btnAlhasyr.setObjectName("btnAlhasyr")
        self.btnAlmumtahinah = QtGui.QPushButton(self.widget)
        self.btnAlmumtahinah.setGeometry(QtCore.QRect(270, 90, 131, 42))
        self.btnAlmumtahinah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmumtahinah.setStyleSheet("background-image: url(:/images/almumtahinah.jpg);")
        self.btnAlmumtahinah.setObjectName("btnAlmumtahinah")
        self.btnAsshof = QtGui.QPushButton(self.widget)
        self.btnAsshof.setGeometry(QtCore.QRect(270, 130, 131, 42))
        self.btnAsshof.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAsshof.setStyleSheet("background-image: url(:/images/asshof.jpg);")
        self.btnAsshof.setObjectName("btnAsshof")
        self.btnAljumah = QtGui.QPushButton(self.widget)
        self.btnAljumah.setGeometry(QtCore.QRect(270, 170, 131, 42))
        self.btnAljumah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAljumah.setStyleSheet("background-image: url(:/images/aljumah.jpg);")
        self.btnAljumah.setObjectName("btnAljumah")
        self.btnAlmunafiqun = QtGui.QPushButton(self.widget)
        self.btnAlmunafiqun.setGeometry(QtCore.QRect(270, 210, 131, 42))
        self.btnAlmunafiqun.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmunafiqun.setStyleSheet("background-image: url(:/images/almunafiqun.jpg);")
        self.btnAlmunafiqun.setObjectName("btnAlmunafiqun")
        self.btnAttaghobun = QtGui.QPushButton(self.widget)
        self.btnAttaghobun.setGeometry(QtCore.QRect(270, 250, 131, 42))
        self.btnAttaghobun.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAttaghobun.setStyleSheet("background-image: url(:/images/attaghobun.jpg);")
        self.btnAttaghobun.setObjectName("btnAttaghobun")
        self.btnAttholaq = QtGui.QPushButton(self.widget)
        self.btnAttholaq.setGeometry(QtCore.QRect(270, 290, 131, 42))
        self.btnAttholaq.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAttholaq.setStyleSheet("background-image: url(:/images/attholaq.jpg);")
        self.btnAttholaq.setObjectName("btnAttholaq")
        self.btnAttahrim = QtGui.QPushButton(self.widget)
        self.btnAttahrim.setGeometry(QtCore.QRect(270, 330, 131, 42))
        self.btnAttahrim.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAttahrim.setStyleSheet("background-image: url(:/images/attahrim.jpg);")
        self.btnAttahrim.setObjectName("btnAttahrim")
        self.btnAlmulk = QtGui.QPushButton(self.widget)
        self.btnAlmulk.setGeometry(QtCore.QRect(270, 370, 131, 42))
        self.btnAlmulk.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmulk.setStyleSheet("background-image: url(:/images/almulk.jpg);")
        self.btnAlmulk.setObjectName("btnAlmulk")
        self.btnAlqolam = QtGui.QPushButton(self.widget)
        self.btnAlqolam.setGeometry(QtCore.QRect(270, 410, 131, 42))
        self.btnAlqolam.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlqolam.setStyleSheet("background-image: url(:/images/alqolam.jpg);")
        self.btnAlqolam.setObjectName("btnAlqolam")
        self.btnAlhaqqoh = QtGui.QPushButton(self.widget)
        self.btnAlhaqqoh.setGeometry(QtCore.QRect(270, 450, 131, 42))
        self.btnAlhaqqoh.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlhaqqoh.setStyleSheet("background-image: url(:/images/alhaqqoh.jpg);")
        self.btnAlhaqqoh.setObjectName("btnAlhaqqoh")
        self.btnAlmaarij = QtGui.QPushButton(self.widget)
        self.btnAlmaarij.setGeometry(QtCore.QRect(270, 490, 131, 42))
        self.btnAlmaarij.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmaarij.setStyleSheet("background-image: url(:/images/almaarij.jpg);")
        self.btnAlmaarij.setObjectName("btnAlmaarij")
        self.btnNuh = QtGui.QPushButton(self.widget)
        self.btnNuh.setGeometry(QtCore.QRect(270, 530, 131, 42))
        self.btnNuh.setMinimumSize(QtCore.QSize(131, 42))
        self.btnNuh.setStyleSheet("background-image: url(:/images/nuh.jpg);")
        self.btnNuh.setObjectName("btnNuh")
        self.btnAljin = QtGui.QPushButton(self.widget)
        self.btnAljin.setGeometry(QtCore.QRect(270, 570, 131, 42))
        self.btnAljin.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAljin.setStyleSheet("background-image: url(:/images/aljin.jpg);")
        self.btnAljin.setObjectName("btnAljin")
        self.btnAlmuzammil = QtGui.QPushButton(self.widget)
        self.btnAlmuzammil.setGeometry(QtCore.QRect(270, 610, 131, 42))
        self.btnAlmuzammil.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmuzammil.setStyleSheet("background-image: url(:/images/almuzammil.jpg);")
        self.btnAlmuzammil.setObjectName("btnAlmuzammil")
        self.btnAlmudatstsir = QtGui.QPushButton(self.widget)
        self.btnAlmudatstsir.setGeometry(QtCore.QRect(270, 650, 131, 42))
        self.btnAlmudatstsir.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmudatstsir.setStyleSheet("background-image: url(:/images/almudatstsir.jpg);")
        self.btnAlmudatstsir.setObjectName("btnAlmudatstsir")
        self.btnAlqiyamah = QtGui.QPushButton(self.widget)
        self.btnAlqiyamah.setGeometry(QtCore.QRect(270, 690, 131, 42))
        self.btnAlqiyamah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlqiyamah.setStyleSheet("background-image: url(:/images/alqiyamah.jpg);")
        self.btnAlqiyamah.setObjectName("btnAlqiyamah")
        self.btnAlinsan = QtGui.QPushButton(self.widget)
        self.btnAlinsan.setGeometry(QtCore.QRect(270, 730, 131, 42))
        self.btnAlinsan.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlinsan.setStyleSheet("background-image: url(:/images/alinsan.jpg);")
        self.btnAlinsan.setObjectName("btnAlinsan")
        self.btnAlmursalat = QtGui.QPushButton(self.widget)
        self.btnAlmursalat.setGeometry(QtCore.QRect(140, 10, 131, 42))
        self.btnAlmursalat.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmursalat.setStyleSheet("background-image: url(:/images/almursalat.jpg);")
        self.btnAlmursalat.setObjectName("btnAlmursalat")
        self.btnAnnaba = QtGui.QPushButton(self.widget)
        self.btnAnnaba.setGeometry(QtCore.QRect(140, 50, 131, 42))
        self.btnAnnaba.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnaba.setStyleSheet("background-image: url(:/images/annaba.jpg);")
        self.btnAnnaba.setObjectName("btnAnnaba")
        self.btnAnnaziat = QtGui.QPushButton(self.widget)
        self.btnAnnaziat.setGeometry(QtCore.QRect(140, 90, 131, 42))
        self.btnAnnaziat.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnaziat.setStyleSheet("background-image: url(:/images/annaziat.jpg);")
        self.btnAnnaziat.setObjectName("btnAnnaziat")
        self.btnAbasa = QtGui.QPushButton(self.widget)
        self.btnAbasa.setGeometry(QtCore.QRect(140, 130, 131, 42))
        self.btnAbasa.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAbasa.setStyleSheet("background-image: url(:/images/abasa.jpg);")
        self.btnAbasa.setObjectName("btnAbasa")
        self.btnAttakwir = QtGui.QPushButton(self.widget)
        self.btnAttakwir.setGeometry(QtCore.QRect(140, 170, 131, 42))
        self.btnAttakwir.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAttakwir.setStyleSheet("background-image: url(:/images/attakwir.jpg);")
        self.btnAttakwir.setObjectName("btnAttakwir")
        self.btnAlinfithor = QtGui.QPushButton(self.widget)
        self.btnAlinfithor.setGeometry(QtCore.QRect(140, 210, 131, 42))
        self.btnAlinfithor.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlinfithor.setStyleSheet("background-image: url(:/images/alinfithor.jpg);")
        self.btnAlinfithor.setObjectName("btnAlinfithor")
        self.btnAlmuthoffifin = QtGui.QPushButton(self.widget)
        self.btnAlmuthoffifin.setGeometry(QtCore.QRect(140, 250, 131, 42))
        self.btnAlmuthoffifin.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmuthoffifin.setStyleSheet("background-image: url(:/images/almuthoffifin.jpg);")
        self.btnAlmuthoffifin.setObjectName("btnAlmuthoffifin")
        self.btnAlinsyiqoq = QtGui.QPushButton(self.widget)
        self.btnAlinsyiqoq.setGeometry(QtCore.QRect(140, 290, 131, 42))
        self.btnAlinsyiqoq.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlinsyiqoq.setStyleSheet("background-image: url(:/images/alinsyiqoq.jpg);")
        self.btnAlinsyiqoq.setObjectName("btnAlinsyiqoq")
        self.btnAlburuj = QtGui.QPushButton(self.widget)
        self.btnAlburuj.setGeometry(QtCore.QRect(140, 330, 131, 42))
        self.btnAlburuj.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlburuj.setStyleSheet("background-image: url(:/images/alburuj.jpg);")
        self.btnAlburuj.setObjectName("btnAlburuj")
        self.btnAtthoriq = QtGui.QPushButton(self.widget)
        self.btnAtthoriq.setGeometry(QtCore.QRect(140, 370, 131, 42))
        self.btnAtthoriq.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAtthoriq.setStyleSheet("background-image: url(:/images/atthoriq.jpg);")
        self.btnAtthoriq.setObjectName("btnAtthoriq")
        self.btnAla3la = QtGui.QPushButton(self.widget)
        self.btnAla3la.setGeometry(QtCore.QRect(140, 410, 131, 42))
        self.btnAla3la.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAla3la.setStyleSheet("background-image: url(:/images/ala3la.jpg);")
        self.btnAla3la.setObjectName("btnAla3la")
        self.btnAlghosyiyah = QtGui.QPushButton(self.widget)
        self.btnAlghosyiyah.setGeometry(QtCore.QRect(140, 450, 131, 42))
        self.btnAlghosyiyah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlghosyiyah.setStyleSheet("background-image: url(:/images/alghosyiyah.jpg);")
        self.btnAlghosyiyah.setObjectName("btnAlghosyiyah")
        self.btnAlfajr = QtGui.QPushButton(self.widget)
        self.btnAlfajr.setGeometry(QtCore.QRect(140, 490, 131, 42))
        self.btnAlfajr.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlfajr.setStyleSheet("background-image: url(:/images/alfajr.jpg);")
        self.btnAlfajr.setObjectName("btnAlfajr")
        self.btnAlbalad = QtGui.QPushButton(self.widget)
        self.btnAlbalad.setGeometry(QtCore.QRect(140, 530, 131, 42))
        self.btnAlbalad.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlbalad.setStyleSheet("background-image: url(:/images/albalad.jpg);")
        self.btnAlbalad.setObjectName("btnAlbalad")
        self.btnAssyams = QtGui.QPushButton(self.widget)
        self.btnAssyams.setGeometry(QtCore.QRect(140, 570, 131, 42))
        self.btnAssyams.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAssyams.setStyleSheet("background-image: url(:/images/assyams.jpg);")
        self.btnAssyams.setObjectName("btnAssyams")
        self.btnAllail = QtGui.QPushButton(self.widget)
        self.btnAllail.setGeometry(QtCore.QRect(140, 610, 131, 42))
        self.btnAllail.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAllail.setStyleSheet("background-image: url(:/images/allail.jpg);")
        self.btnAllail.setObjectName("btnAllail")
        self.btnAddhuha = QtGui.QPushButton(self.widget)
        self.btnAddhuha.setGeometry(QtCore.QRect(140, 650, 131, 42))
        self.btnAddhuha.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAddhuha.setStyleSheet("background-image: url(:/images/addhuha.jpg);")
        self.btnAddhuha.setObjectName("btnAddhuha")
        self.btnAssyarh = QtGui.QPushButton(self.widget)
        self.btnAssyarh.setGeometry(QtCore.QRect(140, 690, 131, 42))
        self.btnAssyarh.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAssyarh.setStyleSheet("background-image: url(:/images/assyarh.jpg);")
        self.btnAssyarh.setObjectName("btnAssyarh")
        self.btnAtthin = QtGui.QPushButton(self.widget)
        self.btnAtthin.setGeometry(QtCore.QRect(140, 730, 131, 42))
        self.btnAtthin.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAtthin.setStyleSheet("background-image: url(:/images/atthin.jpg);")
        self.btnAtthin.setObjectName("btnAtthin")
        self.btnAlalaq = QtGui.QPushButton(self.widget)
        self.btnAlalaq.setGeometry(QtCore.QRect(10, 10, 131, 42))
        self.btnAlalaq.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlalaq.setStyleSheet("background-image: url(:/images/alalaq.jpg);")
        self.btnAlalaq.setObjectName("btnAlalaq")
        self.btnAlqodar = QtGui.QPushButton(self.widget)
        self.btnAlqodar.setGeometry(QtCore.QRect(10, 50, 131, 42))
        self.btnAlqodar.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlqodar.setStyleSheet("background-image: url(:/images/alqodar.jpg);")
        self.btnAlqodar.setObjectName("btnAlqodar")
        self.btnAlbayyinah = QtGui.QPushButton(self.widget)
        self.btnAlbayyinah.setGeometry(QtCore.QRect(10, 90, 131, 42))
        self.btnAlbayyinah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlbayyinah.setStyleSheet("background-image: url(:/images/albayyinah.jpg);")
        self.btnAlbayyinah.setObjectName("btnAlbayyinah")
        self.btnAlzalzalah = QtGui.QPushButton(self.widget)
        self.btnAlzalzalah.setGeometry(QtCore.QRect(10, 130, 131, 42))
        self.btnAlzalzalah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlzalzalah.setStyleSheet("background-image: url(:/images/alzalzalah.jpg);")
        self.btnAlzalzalah.setObjectName("btnAlzalzalah")
        self.btnAladiyat = QtGui.QPushButton(self.widget)
        self.btnAladiyat.setGeometry(QtCore.QRect(10, 170, 131, 42))
        self.btnAladiyat.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAladiyat.setStyleSheet("background-image: url(:/images/aladiyat.jpg);")
        self.btnAladiyat.setObjectName("btnAladiyat")
        self.btnAlqoriah = QtGui.QPushButton(self.widget)
        self.btnAlqoriah.setGeometry(QtCore.QRect(10, 210, 131, 42))
        self.btnAlqoriah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlqoriah.setStyleSheet("background-image: url(:/images/alqoriah.jpg);")
        self.btnAlqoriah.setObjectName("btnAlqoriah")
        self.btnAttakatsur = QtGui.QPushButton(self.widget)
        self.btnAttakatsur.setGeometry(QtCore.QRect(10, 250, 131, 42))
        self.btnAttakatsur.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAttakatsur.setStyleSheet("background-image: url(:/images/attakatsur.jpg);")
        self.btnAttakatsur.setObjectName("btnAttakatsur")
        self.btnAlashr = QtGui.QPushButton(self.widget)
        self.btnAlashr.setGeometry(QtCore.QRect(10, 290, 131, 42))
        self.btnAlashr.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlashr.setStyleSheet("background-image: url(:/images/alashr.jpg);")
        self.btnAlashr.setObjectName("btnAlashr")
        self.btnAlhumazah = QtGui.QPushButton(self.widget)
        self.btnAlhumazah.setGeometry(QtCore.QRect(10, 330, 131, 42))
        self.btnAlhumazah.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlhumazah.setStyleSheet("background-image: url(:/images/alhumazah.jpg);")
        self.btnAlhumazah.setObjectName("btnAlhumazah")
        self.btnAlfiil = QtGui.QPushButton(self.widget)
        self.btnAlfiil.setGeometry(QtCore.QRect(10, 370, 131, 42))
        self.btnAlfiil.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlfiil.setStyleSheet("background-image: url(:/images/alfiil.jpg);")
        self.btnAlfiil.setObjectName("btnAlfiil")
        self.btnQuraisy = QtGui.QPushButton(self.widget)
        self.btnQuraisy.setGeometry(QtCore.QRect(10, 410, 131, 42))
        self.btnQuraisy.setMinimumSize(QtCore.QSize(131, 42))
        self.btnQuraisy.setStyleSheet("background-image: url(:/images/quraisy.jpg);")
        self.btnQuraisy.setObjectName("btnQuraisy")
        self.btnAlmaun = QtGui.QPushButton(self.widget)
        self.btnAlmaun.setGeometry(QtCore.QRect(10, 450, 131, 42))
        self.btnAlmaun.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmaun.setStyleSheet("background-image: url(:/images/almaun.jpg);")
        self.btnAlmaun.setObjectName("btnAlmaun")
        self.btnAlkautsar = QtGui.QPushButton(self.widget)
        self.btnAlkautsar.setGeometry(QtCore.QRect(10, 490, 131, 42))
        self.btnAlkautsar.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlkautsar.setStyleSheet("background-image: url(:/images/alkautsar.jpg);")
        self.btnAlkautsar.setObjectName("btnAlkautsar")
        self.btnAlkafirun = QtGui.QPushButton(self.widget)
        self.btnAlkafirun.setGeometry(QtCore.QRect(10, 530, 131, 42))
        self.btnAlkafirun.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlkafirun.setStyleSheet("background-image: url(:/images/alkafirun.jpg);")
        self.btnAlkafirun.setObjectName("btnAlkafirun")
        self.btnAnnashr = QtGui.QPushButton(self.widget)
        self.btnAnnashr.setGeometry(QtCore.QRect(10, 570, 131, 42))
        self.btnAnnashr.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnashr.setStyleSheet("background-image: url(:/images/annashr.jpg);")
        self.btnAnnashr.setObjectName("btnAnnashr")
        self.btnAlmasad = QtGui.QPushButton(self.widget)
        self.btnAlmasad.setGeometry(QtCore.QRect(10, 610, 131, 42))
        self.btnAlmasad.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlmasad.setStyleSheet("background-image: url(:/images/almasad.jpg);")
        self.btnAlmasad.setObjectName("btnAlmasad")
        self.btnAlikhlas = QtGui.QPushButton(self.widget)
        self.btnAlikhlas.setGeometry(QtCore.QRect(10, 650, 131, 42))
        self.btnAlikhlas.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlikhlas.setStyleSheet("background-image: url(:/images/alikhlas.jpg);")
        self.btnAlikhlas.setObjectName("btnAlikhlas")
        self.btnAlfalaq = QtGui.QPushButton(self.widget)
        self.btnAlfalaq.setGeometry(QtCore.QRect(10, 690, 131, 42))
        self.btnAlfalaq.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAlfalaq.setStyleSheet("background-image: url(:/images/alfalaq.jpg);")
        self.btnAlfalaq.setObjectName("btnAlfalaq")
        self.btnAnnas = QtGui.QPushButton(self.widget)
        self.btnAnnas.setGeometry(QtCore.QRect(10, 730, 131, 42))
        self.btnAnnas.setMinimumSize(QtCore.QSize(131, 42))
        self.btnAnnas.setStyleSheet("background-image: url(:/images/annas.jpg);")
        self.btnAnnas.setObjectName("btnAnnas")




        MainWindow.setCentralWidget(self.centralwidget)

        self.imgx=770
        self.imgy=1244
        self.minpage=1
        self.maxpage=569



        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 348, 20))
        self.menubar.setObjectName("menubar")
        self.menuMenu = QtGui.QMenu(self.menubar)
        self.menuMenu.setObjectName("menuMenu")
        MainWindow.setMenuBar(self.menubar)
        self.actionAbout = QtGui.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionGoto = QtGui.QAction(MainWindow)
        self.actionGoto.setObjectName("actionGoto")
        self.actionLoad = QtGui.QAction(MainWindow)
        self.actionLoad.setObjectName("actionLoad")
        self.menuMenu.addAction(self.actionGoto)
        self.menuMenu.addSeparator()
        self.menuMenu.addAction(self.actionAbout)
        self.menuMenu.addAction(self.actionLoad)
        self.menubar.addAction(self.menuMenu.menuAction())


        self.retranslateUi(MainWindow)

        QtCore.QObject.connect(self.btnAlfatehah, QtCore.SIGNAL("clicked()"), self.openAlfatehah)
        QtCore.QObject.connect(self.btnAlbaqoroh, QtCore.SIGNAL("clicked()"), self.openAlbaqoroh)
        QtCore.QObject.connect(self.btnAliimron, QtCore.SIGNAL("clicked()"), self.openAliimron)
        QtCore.QObject.connect(self.btnAnnisa, QtCore.SIGNAL("clicked()"), self.openAnnisa)
        QtCore.QObject.connect(self.btnAlmaidah, QtCore.SIGNAL("clicked()"), self.openAlmaidah)
        QtCore.QObject.connect(self.btnAnanam, QtCore.SIGNAL("clicked()"), self.openAnanam)
        QtCore.QObject.connect(self.btnAlarof, QtCore.SIGNAL("clicked()"), self.openAlarof)
        QtCore.QObject.connect(self.btnAlanfal, QtCore.SIGNAL("clicked()"), self.openAlanfal)
        QtCore.QObject.connect(self.btnAttaubah, QtCore.SIGNAL("clicked()"), self.openAttaubah)
        QtCore.QObject.connect(self.btnYunus, QtCore.SIGNAL("clicked()"), self.openYunus)
        QtCore.QObject.connect(self.btnHud, QtCore.SIGNAL("clicked()"), self.openHud)
        QtCore.QObject.connect(self.btnYusuf, QtCore.SIGNAL("clicked()"), self.openYusuf)
        QtCore.QObject.connect(self.btnArroed, QtCore.SIGNAL("clicked()"), self.openArroed)
        QtCore.QObject.connect(self.btnIbrohim, QtCore.SIGNAL("clicked()"), self.openIbrohim)
        QtCore.QObject.connect(self.btnAlhijr, QtCore.SIGNAL("clicked()"), self.openAlhijr)
        QtCore.QObject.connect(self.btnAnnahl, QtCore.SIGNAL("clicked()"), self.openAnnahl)
        QtCore.QObject.connect(self.btnAlisro, QtCore.SIGNAL("clicked()"), self.openAlisro)
        QtCore.QObject.connect(self.btnAlkahf, QtCore.SIGNAL("clicked()"), self.openAlkahf)
        QtCore.QObject.connect(self.btnMaryam, QtCore.SIGNAL("clicked()"), self.openMaryam)

        QtCore.QObject.connect(self.btnThoha, QtCore.SIGNAL("clicked()"), self.openThoha)
        QtCore.QObject.connect(self.btnAlanbiya, QtCore.SIGNAL("clicked()"), self.openAlanbiya)
        QtCore.QObject.connect(self.btnAlhaaj, QtCore.SIGNAL("clicked()"), self.openAlhaaj)
        QtCore.QObject.connect(self.btnAlmukminun, QtCore.SIGNAL("clicked()"), self.openAlmukminun)
        QtCore.QObject.connect(self.btnAnnuur, QtCore.SIGNAL("clicked()"), self.openAnnuur)
        QtCore.QObject.connect(self.btnAlfurqon, QtCore.SIGNAL("clicked()"), self.openAlfurqon)
        QtCore.QObject.connect(self.btnAssyuaro, QtCore.SIGNAL("clicked()"), self.openAssyuaro)
        QtCore.QObject.connect(self.btnAnnaml, QtCore.SIGNAL("clicked()"), self.openAnnaml)
        QtCore.QObject.connect(self.btnAlqoshosh, QtCore.SIGNAL("clicked()"), self.openAlqoshosh)
        QtCore.QObject.connect(self.btnAlankabut, QtCore.SIGNAL("clicked()"), self.openAlankabut)
        QtCore.QObject.connect(self.btnArruum, QtCore.SIGNAL("clicked()"), self.openArruum)
        QtCore.QObject.connect(self.btnLuqman, QtCore.SIGNAL("clicked()"), self.openLuqman)
        QtCore.QObject.connect(self.btnAssajadah, QtCore.SIGNAL("clicked()"), self.openAssajadah)
        QtCore.QObject.connect(self.btnAlahzab, QtCore.SIGNAL("clicked()"), self.openAlahzab)
        QtCore.QObject.connect(self.btnSaba, QtCore.SIGNAL("clicked()"), self.openSaba)
        QtCore.QObject.connect(self.btnFaathir, QtCore.SIGNAL("clicked()"), self.openFaathir)
        QtCore.QObject.connect(self.btnYasin, QtCore.SIGNAL("clicked()"), self.openYasin)
        QtCore.QObject.connect(self.btnAsshoffaat, QtCore.SIGNAL("clicked()"), self.openAsshoffaat)
        QtCore.QObject.connect(self.btnShoot, QtCore.SIGNAL("clicked()"), self.openShoot)

        QtCore.QObject.connect(self.btnAzzumar, QtCore.SIGNAL("clicked()"), self.openAzzumar)
        QtCore.QObject.connect(self.btnGhoofir, QtCore.SIGNAL("clicked()"), self.openGhoofir)
        QtCore.QObject.connect(self.btnFusshilat, QtCore.SIGNAL("clicked()"), self.openFusshilat)
        QtCore.QObject.connect(self.btnAssyuuroo, QtCore.SIGNAL("clicked()"), self.openAssyuuroo)
        QtCore.QObject.connect(self.btnAzzukhruf, QtCore.SIGNAL("clicked()"), self.openAzzukhruf)
        QtCore.QObject.connect(self.btnAddukhon, QtCore.SIGNAL("clicked()"), self.openAddukhon)
        QtCore.QObject.connect(self.btnAljaatsiyah, QtCore.SIGNAL("clicked()"), self.openAljaatsiyah)
        QtCore.QObject.connect(self.btnAlahqoof, QtCore.SIGNAL("clicked()"), self.openAlahqoof)
        QtCore.QObject.connect(self.btnMuhammad, QtCore.SIGNAL("clicked()"), self.openMuhammad)
        QtCore.QObject.connect(self.btnAlfath, QtCore.SIGNAL("clicked()"), self.openAlfath)
        QtCore.QObject.connect(self.btnAlhujurat, QtCore.SIGNAL("clicked()"), self.openAlhujurat)
        QtCore.QObject.connect(self.btnQoof, QtCore.SIGNAL("clicked()"), self.openQoof)
        QtCore.QObject.connect(self.btnAddzaariyat, QtCore.SIGNAL("clicked()"), self.openAddzaariyat)
        QtCore.QObject.connect(self.btnAtthuur, QtCore.SIGNAL("clicked()"), self.openAtthuur)
        QtCore.QObject.connect(self.btnAnnajm, QtCore.SIGNAL("clicked()"), self.openAnnajm)
        QtCore.QObject.connect(self.btnAlqomar, QtCore.SIGNAL("clicked()"), self.openAlqomar)
        QtCore.QObject.connect(self.btnArrohman, QtCore.SIGNAL("clicked()"), self.openArrohman)
        QtCore.QObject.connect(self.btnAlwaqiah, QtCore.SIGNAL("clicked()"), self.openAlwaqiah)
        QtCore.QObject.connect(self.btnAlhadid, QtCore.SIGNAL("clicked()"), self.openAlhadid)

        QtCore.QObject.connect(self.btnAlmujadalah, QtCore.SIGNAL("clicked()"), self.openAlmujadalah)
        QtCore.QObject.connect(self.btnAlhasyr, QtCore.SIGNAL("clicked()"), self.openAlhasyr)
        QtCore.QObject.connect(self.btnAlmumtahinah, QtCore.SIGNAL("clicked()"), self.openAlmumtahinah)
        QtCore.QObject.connect(self.btnAsshof, QtCore.SIGNAL("clicked()"), self.openAsshof)
        QtCore.QObject.connect(self.btnAljumah, QtCore.SIGNAL("clicked()"), self.openAljumah)
        QtCore.QObject.connect(self.btnAlmunafiqun, QtCore.SIGNAL("clicked()"), self.openAlmunafiqun)
        QtCore.QObject.connect(self.btnAttaghobun, QtCore.SIGNAL("clicked()"), self.openAttaghobun)
        QtCore.QObject.connect(self.btnAttholaq, QtCore.SIGNAL("clicked()"), self.openAttholaq)
        QtCore.QObject.connect(self.btnAttahrim, QtCore.SIGNAL("clicked()"), self.openAttahrim)
        QtCore.QObject.connect(self.btnAlmulk, QtCore.SIGNAL("clicked()"), self.openAlmulk)
        QtCore.QObject.connect(self.btnAlqolam, QtCore.SIGNAL("clicked()"), self.openAlqolam)
        QtCore.QObject.connect(self.btnAlhaqqoh, QtCore.SIGNAL("clicked()"), self.openAlhaqqoh)
        QtCore.QObject.connect(self.btnAlmaarij, QtCore.SIGNAL("clicked()"), self.openAlmaarij)
        QtCore.QObject.connect(self.btnNuh, QtCore.SIGNAL("clicked()"), self.openNuh)
        QtCore.QObject.connect(self.btnAljin, QtCore.SIGNAL("clicked()"), self.openAljin)
        QtCore.QObject.connect(self.btnAlmuzammil, QtCore.SIGNAL("clicked()"), self.openAlmuzammil)
        QtCore.QObject.connect(self.btnAlmudatstsir, QtCore.SIGNAL("clicked()"), self.openAlmudatstsir)
        QtCore.QObject.connect(self.btnAlqiyamah, QtCore.SIGNAL("clicked()"), self.openAlqiyamah)
        QtCore.QObject.connect(self.btnAlinsan, QtCore.SIGNAL("clicked()"), self.openAlinsan)

        QtCore.QObject.connect(self.btnAlmursalat, QtCore.SIGNAL("clicked()"), self.openAlmursalat)
        QtCore.QObject.connect(self.btnAnnaba, QtCore.SIGNAL("clicked()"), self.openAnnaba)
        QtCore.QObject.connect(self.btnAnnaziat, QtCore.SIGNAL("clicked()"), self.openAnnaziat)
        QtCore.QObject.connect(self.btnAbasa, QtCore.SIGNAL("clicked()"), self.openAbasa)
        QtCore.QObject.connect(self.btnAttakwir, QtCore.SIGNAL("clicked()"), self.openAttakwir)
        QtCore.QObject.connect(self.btnAlinfithor, QtCore.SIGNAL("clicked()"), self.openAlinfithor)
        QtCore.QObject.connect(self.btnAlmuthoffifin, QtCore.SIGNAL("clicked()"), self.openAlmuthoffifin)
        QtCore.QObject.connect(self.btnAlinsyiqoq, QtCore.SIGNAL("clicked()"), self.openAlinsyiqoq)
        QtCore.QObject.connect(self.btnAlburuj, QtCore.SIGNAL("clicked()"), self.openAlburuj)
        QtCore.QObject.connect(self.btnAtthoriq, QtCore.SIGNAL("clicked()"), self.openAtthoriq)
        QtCore.QObject.connect(self.btnAla3la, QtCore.SIGNAL("clicked()"), self.openAla3la)
        QtCore.QObject.connect(self.btnAlghosyiyah, QtCore.SIGNAL("clicked()"), self.openAlghosyiyah)
        QtCore.QObject.connect(self.btnAlfajr, QtCore.SIGNAL("clicked()"), self.openAlfajr)
        QtCore.QObject.connect(self.btnAlbalad, QtCore.SIGNAL("clicked()"), self.openAlbalad)
        QtCore.QObject.connect(self.btnAssyams, QtCore.SIGNAL("clicked()"), self.openAssyams)
        QtCore.QObject.connect(self.btnAllail, QtCore.SIGNAL("clicked()"), self.openAllail)
        QtCore.QObject.connect(self.btnAddhuha, QtCore.SIGNAL("clicked()"), self.openAddhuha)
        QtCore.QObject.connect(self.btnAssyarh, QtCore.SIGNAL("clicked()"), self.openAssyarh)
        QtCore.QObject.connect(self.btnAtthin, QtCore.SIGNAL("clicked()"), self.openAtthin)

        QtCore.QObject.connect(self.btnAlalaq, QtCore.SIGNAL("clicked()"), self.openAlalaq)
        QtCore.QObject.connect(self.btnAlqodar, QtCore.SIGNAL("clicked()"), self.openAlqodar)
        QtCore.QObject.connect(self.btnAlbayyinah, QtCore.SIGNAL("clicked()"), self.openAlbayyinah)
        QtCore.QObject.connect(self.btnAlzalzalah, QtCore.SIGNAL("clicked()"), self.openAlzalzalah)
        QtCore.QObject.connect(self.btnAladiyat, QtCore.SIGNAL("clicked()"), self.openAladiyat)
        QtCore.QObject.connect(self.btnAlqoriah, QtCore.SIGNAL("clicked()"), self.openAlqoriah)
        QtCore.QObject.connect(self.btnAttakatsur, QtCore.SIGNAL("clicked()"), self.openAttakatsur)
        QtCore.QObject.connect(self.btnAlashr, QtCore.SIGNAL("clicked()"), self.openAlashr)
        QtCore.QObject.connect(self.btnAlhumazah, QtCore.SIGNAL("clicked()"), self.openAlhumazah)
        QtCore.QObject.connect(self.btnAlfiil, QtCore.SIGNAL("clicked()"), self.openAlfiil)
        QtCore.QObject.connect(self.btnQuraisy, QtCore.SIGNAL("clicked()"), self.openQuraisy)
        QtCore.QObject.connect(self.btnAlmaun, QtCore.SIGNAL("clicked()"), self.openAlmaun)
        QtCore.QObject.connect(self.btnAlkautsar, QtCore.SIGNAL("clicked()"), self.openAlkautsar)
        QtCore.QObject.connect(self.btnAlkafirun, QtCore.SIGNAL("clicked()"), self.openAlkafirun)
        QtCore.QObject.connect(self.btnAnnashr, QtCore.SIGNAL("clicked()"), self.openAnnashr)
        QtCore.QObject.connect(self.btnAlmasad, QtCore.SIGNAL("clicked()"), self.openAlmasad)
        QtCore.QObject.connect(self.btnAlikhlas, QtCore.SIGNAL("clicked()"), self.openAlikhlas)
        QtCore.QObject.connect(self.btnAlfalaq, QtCore.SIGNAL("clicked()"), self.openAlfalaq)
        QtCore.QObject.connect(self.btnAnnas, QtCore.SIGNAL("clicked()"), self.openAnnas)






        QtCore.QObject.connect(self.btnNext, QtCore.SIGNAL("clicked()"), self.openNext)
        QtCore.QObject.connect(self.btnPrev, QtCore.SIGNAL("clicked()"), self.openPrev)
        QtCore.QObject.connect(self.btnIndex, QtCore.SIGNAL("clicked()"), self.backtoIndex)
        QtCore.QObject.connect(self.btnExit, QtCore.SIGNAL("clicked()"), self.closeApp)
        QtCore.QObject.connect(self.btnSave, QtCore.SIGNAL("clicked()"), self.savePage)
        QtCore.QObject.connect(self.actionAbout, QtCore.SIGNAL("triggered()"), self.showAbout)
        QtCore.QObject.connect(self.actionGoto, QtCore.SIGNAL("triggered()"), self.showGoto)
        QtCore.QObject.connect(self.actionLoad, QtCore.SIGNAL("triggered()"), self.loadPage)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Quran Mobile for Nokia N900", None, QtGui.QApplication.UnicodeUTF8))
        self.labelPage.setText(QtGui.QApplication.translate("MainWindow", "", None, QtGui.QApplication.UnicodeUTF8))
        self.btnNext.setText(QtGui.QApplication.translate("MainWindow", "Next", None, QtGui.QApplication.UnicodeUTF8))
        self.btnPrev.setText(QtGui.QApplication.translate("MainWindow", "Prev", None, QtGui.QApplication.UnicodeUTF8))
        self.btnIndex.setText(QtGui.QApplication.translate("MainWindow", "Index", None, QtGui.QApplication.UnicodeUTF8))
        self.btnExit.setText(QtGui.QApplication.translate("MainWindow", "Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.btnSave.setText(QtGui.QApplication.translate("MainWindow", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAbout.setText(QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
        self.actionGoto.setText(QtGui.QApplication.translate("MainWindow", "Goto", None, QtGui.QApplication.UnicodeUTF8))
        self.actionLoad.setText(QtGui.QApplication.translate("MainWindow", "Load", None, QtGui.QApplication.UnicodeUTF8))


import quran_rc

if __name__ == "__main__":
    import sys
    app = QtGui.QApplication(sys.argv)
    MainWindow = QtGui.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())

